function evert6(slide) {

var tau=2*Math.PI;

var NB_LAT=64;
var SAUT=8;
var NB_LONG=80;
var arc=1/18;
var He=3;
var ha=1.0*arc*tau;

var slider=document.getElementById("sliderParalTime");
slider.value=0;
var sliderCut=document.getElementById("sliderParalCut");
sliderCut.value=sliderCut.max;

var showI=true;
var showM=false;
var inputI=document.getElementById("cbParalSlices");
var inputM=document.getElementById("cbParalModel");
inputI.checked=showI;
inputM.checked=showM;
inputI.onchange=function () { 
  showI=inputI.checked;  
  for(var i=0; i<lines.length; i++) {
    lines[i].visible=showI;
  }
};
inputM.onchange=function () { 
  showM=inputM.checked;
  shape.visible=showM;
  shape_in.visible=showM;
};

var wi=slide.clientWidth-100;
var he=slide.clientHeight-100;

var scene = new THREE.Scene();
var camera = new THREE.PerspectiveCamera( 30, wi/he, 0.1, 1000 );
camera.up.set(0,0,1);
camera.position.set(0,7,0);
camera.lookAt(new THREE.Vector3(0,0,0));

var renderer = new THREE.WebGLRenderer( { alpha: true });
renderer.setSize(wi,he);
var domel=renderer.domElement;
slide.appendChild(domel);
setStyle(domel,{ "position":"absolute", "left":"50px", "bottom":"50px"})

var controls = new THREE.OrbitControls( camera, domel );
    controls.target.set( 0, 0, 0 );
    controls.enableKeys=false;
    controls.update();

var plane = new THREE.Plane( new THREE.Vector3( 0, 0, -1 ), 10.0 );
renderer.localClippingEnabled = true;

var dirLight1 = new THREE.DirectionalLight( 0xAAFFFF, 0.6 );
var dirLight2 = new THREE.DirectionalLight( 0xFFFFAA, 0.6 );
var posLight1=new THREE.Vector3(-1, 3, 5);
var posLight2=new THREE.Vector3( -2, -4, -4 );
dirLight1.position.copy(posLight1);
dirLight2.position.copy(posLight2);
dirLight1.castShadow = false;
dirLight2.castShadow = false;
scene.add( dirLight1 );
scene.add( dirLight2 );
      
var ambLight = new THREE.AmbientLight( 0xFFFFFF, 0.4 );
scene.add( ambLight );

function getZ(i) {
  return (i/NB_LAT-0.5)*He;
}

var prox = function(x) {
  return Math.floor(x+0.5);
}

var norm=function(v) {
  return(Math.sqrt(v.x*v.x+v.y*v.y));
}

function lin(a,b,t) {
  return((1-t)*a+t*b);
}

function polar(r,th) {
  var rh=Math.exp(r-1);
  return({
    x:rh*Math.cos(th)
   ,y:rh*Math.sin(th)
  });
}

var st=2*arc+(1-2*arc)/9;

function g(s0,t) { // s0 : arc parameter, t: time parameter
//  var de=t*(1-2*arc)/2;
  var de=arc/2/st;
  var delta=-tau*arc/2;
  var s1=s0+de;
  s1=s1-Math.floor(s1);
  var s=s1*st;
  if(s<arc) {
    var x=s/arc; 
    var r=1-ha*(1-Math.cos(tau*x))/2;
    var th=tau*arc*(x*(4*x-3)*(4*x-3));
    return polar(r,th+delta);
  }
  var u=lin(arc,st-arc,t);
  var v=lin(arc,1-arc,t);
  if(s<u)
    return polar(1,delta+tau*lin(arc,v,(s-arc)/(u-arc)));
  if(s<arc+u) { 
    var x=(s-u)/arc;
    var r=1+ha*(1-Math.cos(tau*x))/2;
    var th=tau*(v+arc*x*(4*x-3)*(4*x-3));
    return polar(r,th+delta);
  }
  return polar(1,delta+tau*lin(v+arc,1,(s-(u+arc))/(st-(u+arc))));
}

var mesh = new THREE.Geometry();

orig1=[];
orig2=[];
origDir1=[];
origDir2=[];
origLen1=[];
origL1=[];
for(var i=0; i<=NB_LAT; i++) {
  var curve1=[];
  var dir1=[];
  var ti=i/NB_LAT;
  for(var j=0; j<NB_LONG; j++) {
    var p=g(j/NB_LONG,ti);
    curve1.push(p);
  }
  orig1.push(curve1);

  var aux=0;
  var v={x:0,y:1};
  var L1=0;
  var len1=[];
  for(var j=0; j<=NB_LONG; j++) {
    var q=curve1[j%NB_LONG];
    var p=curve1[(j+1)%NB_LONG];
    var nv={x:p.x-q.x, y:p.y-q.y};
    var r=norm(nv);
    var naux = Math.atan2(nv.y,nv.x); 
    aux = naux - tau*prox((naux-aux)/tau); 
    dir1.push({x:r, y:aux});
    len1.push(L1);
    if(i<NB_LONG) L1 += r;
    v=nv;
  }
  origDir1.push(dir1);
  origLen1.push(len1);
  origL1.push(L1);

  var curve2=[];
  var dir2=[];
  var r=L1/tau;
  for(var j=0; j<NB_LONG; j++) {
    var th=tau/2+tau*len1[j]/L1; 
    curve2.push(polar(r,th));
  }
  orig2.push(curve2);
  aux=0;
  v={x:0,y:1};
  for(var j=0; j<=NB_LONG; j++) {
    var q=curve2[j%NB_LONG];
    var p=curve2[(j+1)%NB_LONG];
    var nv={x:p.x-q.x, y:p.y-q.y};
    var r=norm(nv);
    var naux = Math.atan2(nv.y,nv.x);
    aux = naux - tau*prox((naux-aux)/tau);
    var temp={x:r, y:aux};
    dir2.push({x:r, y:aux});
    v=nv;
  }
  origDir2.push(dir2);
}

for(var i=0; i<=NB_LAT; i++) {
  var z=getZ(i);
  for(var j=0; j<NB_LONG; j++) {
    var p=orig1[i][j]; 
    mesh.vertices.push(new THREE.Vector3(p.x,p.y,z));
  }
}

line_mesh = new THREE.Geometry();
for(var j=0; j<=NB_LONG; j++) {
  var z=getZ(0);
  var p=orig1[0][j%NB_LONG]; 
  line_mesh.vertices.push(new THREE.Vector3(p.x,p.y,z));
}
// for(var i=0; i<=NB_LAT; i++) {
//   var z=getZ(i);
//     var p=orig1[i][0]; 
//       line_mesh.vertices.push(new THREE.Vector3(p.x,p.y,z));
// }

var offset=0;

offset=mesh_push_cyl(mesh,NB_LAT,NB_LONG,offset);

mesh.computeVertexNormals();

var shape_inter;

var material = new THREE.MeshLambertMaterial( {
          color: 0x80ee10,
          side: THREE.BackSide,
          clippingPlanes: [ plane ],
//						clipShadows: true
        } );

var material2 = new THREE.MeshLambertMaterial( {
          color: 0xee8010,
          side: THREE.FrontSide,
          clippingPlanes: [ plane ],
//						clipShadows: true
        } );

var material3 = new THREE.MeshLambertMaterial( {
          color: 0xA00080,
          side: THREE.DoubleSide,
          clippingPlanes: [ plane ],
//						clipShadows: true
        } );

var material4 = new THREE.LineBasicMaterial({
        color: 0x0000ff, linewidth: 3, clippingPlanes: [ plane ],
    });
    
var shape = new THREE.Mesh( mesh, material2 );
var shape_in = new THREE.Mesh( mesh, material );
scene.add( shape );
scene.add( shape_in );
shape.visible=showM;
shape_in.visible=showM;

var lines_geom=[];
for(var i=0; i<=NB_LAT; i+=SAUT) {
  lines_geom.push(line_mesh.clone());
}
var lines=[];
for(var i=0; i<lines_geom.length; i++) {
  lines.push(new THREE.Line(lines_geom[i],material4));
  lines[i].visible=showI;
  scene.add( lines[i] );
}

//scene.add(shape_inter);

//shape.rotateY( Math.PI / 2);
//shape_in.rotateY( Math.PI / 2);
  
var stopRender=false;

var render = function () {
  if(!stopRender) requestAnimationFrame( render );

  var phi=-(tau/4-controls.getPolarAngle());
  var theta=controls.getAzimuthalAngle()+tau/4;
    
  var m1=new THREE.Matrix4();
  var m2=new THREE.Matrix4();
  var m=new THREE.Matrix4();
  m1.makeRotationZ(theta);
  m2.makeRotationY(-phi);
  m.multiplyMatrices(m1,m2);

  dirLight1.position.copy(posLight1);
  dirLight2.position.copy(posLight2);
  dirLight1.position.applyMatrix4(m);
  dirLight2.position.applyMatrix4(m);

  var tm = slider.value/slider.max;

  var aux = sliderCut.value/sliderCut.max;
  plane.constant = He*(aux-0.5);

  var ve=mesh.vertices; 

  var curve;
  for(var i=0; i<=NB_LAT; i++) {
    var x=0,y=0;
    curve=[{x:x,y:y}];
    var dir1=origDir1[i];
    var len1=origLen1[i];
    var dir2=origDir2[i];
    var L1=origL1[i];
    for(var j=1; j<=NB_LONG; j++) {
      var a=(1-tm)*dir1[j].y+tm*dir2[j].y;
      var r=(1-tm)*dir1[j].x+tm*dir2[j].x;
      x += r*Math.cos(a);
      y += r*Math.sin(a);
      if(j<NB_LONG) curve.push({x:x,y:y});
    }
    var bx=0,by=0;
    for(var j=1; j<NB_LONG; j++) {
      var s=len1[j]/L1;
      curve[j].x -= s*x;
      curve[j].y -= s*y;
      var ds=(len1[j]-len1[j-1])/L1;
      bx += ds*curve[j].x;
      by += ds*curve[j].y;
    }
//     for(var j=0; j<NB_LONG; j++) {
//       curve[j].x -= bx;
//       curve[j].y -= by;
//     }
    redr={x:curve[1].x-curve[0].x
         ,y:curve[1].y-curve[0].y};
    var d=norm(redr);
    redr.x /= d;
    redr.y /= d;
    redr.y = -redr.y;
    redr={x:-redr.y,y:redr.x};
    for(var j=0; j<NB_LONG; j++) {
      curve[j].x -= bx;
      curve[j].y -= by;
      var nx = curve[j].x*redr.x - curve[j].y*redr.y;
      var ny = curve[j].x*redr.y + curve[j].y*redr.x;
      curve[j].x = nx;
      curve[j].y = ny;
    }
      
    var z=getZ(i);
    for(var j=0; j<NB_LONG; j++) {
      var k=i*NB_LONG+j;
      
      ve[k].x=curve[j].x;
      ve[k].y=curve[j].y;
      ve[k].z=z;
    }
  }
  for(var m=0; m*SAUT<=NB_LAT; m++) {
    var i=m*SAUT;
    for(var j=0; j<=NB_LONG; j++) {
      var k=i*NB_LONG+(j%NB_LONG);
      lines_geom[m].vertices[j]=ve[k].clone();
    }
    lines_geom[m].verticesNeedUpdate=true;
  }
  /*
  for(var i=0; i<=NB_LAT; i++) {
      var k=i*NB_LONG+0;
      line_mesh.vertices[i]=ve[k].clone();
  }
  */
  
  mesh.verticesNeedUpdate=true;
  mesh.computeVertexNormals();
  
  renderer.render(scene, camera);
};

var slideEnter = function() {
  stopRender=false;
  render();
}
var slideLeave = function() {
  stopRender=true;
}
slide.addEventListener("impress:stepenter",slideEnter,false);
slide.addEventListener("impress:stepleave",slideLeave,false);
};